@@ -11,7 +11,7 @@
 #' @param privileged factor/character, one value of \code{protected}, in regard to what subgroup parity loss is calculated
 #' @param cutoff numeric, vector of cutoffs (thresholds) for each value of protected variable, affecting only explainers.
 #' @param label character, vector of labels to be assigned for explainers, default is explainer label.
-#' @param epsilon numeric, boundary for fairness checking, lowest acceptable ratio of metrics
+#' @param epsilon numeric, boundary for fairness checking, lowest acceptable ratio of metrics between unprivileged and privileged subgroups. Default value is 0.8. More on the idea behind epsilon in details section.
 #' @param verbose logical, whether to print information about creation of fairness object
 #' @param colorize logical, whether to print information in color
 #'
@@ -21,9 +21,9 @@
 #' Metrics used are made for each subgroup, then base metric score is subtracted leaving loss of particular metric.
 #' If absolute loss of metrics ratio is not within acceptable boundaries than such metric is marked as "not passed". It means that values of metrics should be within (epsilon, 1/epsilon) boundary.
 #' The default ratio is set to 0.8 which adhere to US 80% rule (more on it here: \url{https://en.wikipedia.org/wiki/Disparate_impact#The_80%_rule}). It means that unprivileged subgroups should have at least 80%
-#' of scores achieved in metrics by privileged subgroup. For example if TPR_unprivileged/TPR_privileged is less than 0.8 then such ratio is sign of discrimination. On the other hand if
+#' score achieved in metrics by privileged subgroup. For example if TPR_unprivileged/TPR_privileged is less than 0.8 then such ratio is sign of discrimination. On the other hand if
 #' TPR_privileged/TPR_unprivileged is more than 1.25 (1/0.8) than there is discrimination towards privileged group.
-#' Epsilon value can be adjusted to user's needs. There are some metrics that might be derived from existing metrics (For example Equalized Odds - equal TPR and FPR for all subgroups).
+#' Epsilon value can be adjusted to user's needs. It should be interpreted as the lowest ratio of metrics allowed.  There are some metrics that might be derived from existing metrics (For example Equalized Odds - equal TPR and FPR for all subgroups).
 #' That means passing 5 metrics in fairness check asserts that model is even more fair. In \code{fairness_check} models must always predict positive result. Not adhering to this rule
 #' may lead to misinterpretation of the plot. More on metrics and their equivalents:
 #' \url{https://fairware.cs.umass.edu/papers/Verma.pdf}
@@ -78,6 +78,7 @@
 #'
 #' Verma, Rubin (2018) \url{https://fairware.cs.umass.edu/papers/Verma.pdf}
 #'
+#' Barocas, Hardt, Narayanan (2019) \url{https://fairmlbook.org/}
 #'
 #' @export
 #' @rdname fairness_check
@@ -91,6 +92,14 @@
 #'                 data = german,
 #'                 family=binomial(link="logit"))
 #'
+#' explainer_lm <- DALEX::explain(lm_model, data = german[,-1], y = y_numeric)
+#'
+#' fobject <- fairness_check(explainer_lm,
+#'                           protected = german$Sex,
+#'                           privileged = "male")
+#' plot(fobject)
+#'
+#' \donttest{
 #' rf_model <- ranger::ranger(Risk ~.,
 #'                            data = german,
 #'                            probability = TRUE,
@@ -98,18 +107,15 @@
 #'                            num.trees = 100,
 #'                            seed = 1)
 #'
-#' explainer_lm <- DALEX::explain(lm_model, data = german[,-1], y = y_numeric)
 #'
 #' explainer_rf <- DALEX::explain(rf_model,
 #'                                data = german[,-1],
 #'                                y = y_numeric)
 #'
-#' fobject <- fairness_check(explainer_lm, explainer_rf,
-#'                           protected = german$Sex,
-#'                           privileged = "male")
+#' fobject <- fairness_check(explainer_rf, fobject)
 #'
 #' plot(fobject)
-#'
+#'}
 
 
 fairness_check <- function(x,
@@ -325,6 +331,7 @@ fairness_check <- function(x,
   df                <- data.frame()
   cutoffs           <- as.list(rep(0, n_exp))
   names(cutoffs)    <- label
+  parity_loss_names <- NULL
 
   for (i in seq_along(explainers)) {
     # note that this is along explainers passed to fc, not all_explainers (eg from fairness_objects)
@@ -345,6 +352,7 @@ fairness_check <- function(x,
     # parity_loss
     parity_loss <- calculate_parity_loss(gmm, privileged)
     parity_loss_metric_data[i, ] <- parity_loss
+    parity_loss_names <- names(parity_loss)
 
 
     # every group value for every metric for every explainer
@@ -434,7 +442,10 @@ fairness_check <- function(x,
 
   # as data frame and making numeric
   parity_loss_metric_data           <- as.data.frame(parity_loss_metric_data)
-  colnames(parity_loss_metric_data) <- names(parity_loss)
+
+  if (is.null(parity_loss_names)) parity_loss_names <- names(parity_loss_metric_data)
+  colnames(parity_loss_metric_data) <- parity_loss_names
+
 
 
   # merge explainers data with fobjects
